@@ -192,6 +192,7 @@ EqualsData = wrap_builtin_binop(uplc_ast.BuiltInFun.EqualsData)
 MkPairData = wrap_builtin_binop(uplc_ast.BuiltInFun.MkPairData)
 MkNilData = wrap_builtin_unop(uplc_ast.BuiltInFun.MkNilData)
 MkNilPairData = wrap_builtin_unop(uplc_ast.BuiltInFun.MkNilPairData)
+SerialiseData = wrap_builtin_unop(uplc_ast.BuiltInFun.SerialiseData)
 
 # Generic Utils
 
@@ -592,3 +593,22 @@ def DelayedChooseData(
             Delay(bytestring_branch),
         )
     )
+
+
+# concatenation utils
+
+
+def _concat(append, empty):
+    def f(*ss: typing.List[AST]):
+        if not ss:
+            return empty
+        c = ss[-1]
+        for s in reversed(ss[:-1]):
+            c = append(s, c)
+        return c
+
+    return f
+
+
+ConcatString = _concat(AppendString, Text(""))
+ConcatByteString = _concat(AppendByteString, ByteString(b""))
